@@ -557,6 +557,29 @@ void	PrintStringList(const char *cmd, const ConfigValue &cfg)
 		cout << '\n';
 }
 
+void	PrintStringListNoGlob(const char *cmd, const ConfigValue &cfg)
+{
+	cout << cmd << ": ";
+
+	bool	indent = false;
+	size_t	num_indent = strlen(cmd)+2;
+
+	for (DirList::iterator iter = (allConfig[configProfile].*cfg.cfgStringListPtr)->begin(); 
+	     iter != (allConfig[configProfile].*cfg.cfgStringListPtr)->end(); ++iter) {
+		if (indent) {
+			for (size_t i = 0; i < num_indent; ++i)
+				cout << ' ';
+		}
+		else
+			indent = true; 
+		cout << (*iter)->dir << '\n';
+	}
+
+				// List is empty
+	if (! indent)
+		cout << '\n';
+}
+
 /*************************************************************************
 	Command processing/printing functions - Clear string list.
 *************************************************************************/
@@ -924,12 +947,13 @@ ConfigFunc cfgFuncYesNo = { ConfigYesNo, PrintYesNo };
 ConfigFunc cfgFuncUnsigned = { ConfigUnsigned, PrintUnsigned };
 ConfigFunc cfgFuncKeyBinding = { ConfigKeyBinding, PrintKeyBinding };
 ConfigFunc cfgFuncStringList = { ConfigStringList, PrintStringList };
+ConfigFunc cfgFuncStringListNoGlob = { ConfigStringList, PrintStringListNoGlob };
 ConfigFunc cfgFuncClearStringList = { ConfigClearStringList, 0 };
 ConfigFunc cfgFuncColorAttr = { ConfigColorAttr, PrintColorAttr };
 ConfigFunc cfgFuncColor = { ConfigColor, PrintColor };
 ConfigFunc cfgFuncBWAttr = { ConfigBWAttr, PrintBWAttr };
 
-#define NUM_CONFIG_INFO	41
+#define NUM_CONFIG_INFO	42
 ConfigInfo configInfo[NUM_CONFIG_INFO] = {
 	{ "QuietFullScan", &cfgFuncYesNo, { 0, 0, &KcdConfig::cfgQuietFull, 0, 0, 0 } },
 	{ "QuietSmartScan", &cfgFuncYesNo, { 0, 0, &KcdConfig::cfgQuietSmart, 0, 0, 0 } },
@@ -951,6 +975,8 @@ ConfigInfo configInfo[NUM_CONFIG_INFO] = {
 	{ "StartDir", &cfgFuncStringList, { 0, 0, 0, &KcdConfig::cfgStartDir, 0, 0 } },
 	{ "SkipDir", &cfgFuncStringList, { 0, 0, 0, &KcdConfig::cfgSkipDir, 0, 0 } },
 
+	{ "DefaultTree", &cfgFuncStringListNoGlob, { 0, 0, 0, &KcdConfig::cfgDefaultTree, 0, 0 } },
+
 	{ "ClearStartDir", &cfgFuncClearStringList, { 0, 0, 0, &KcdConfig::cfgStartDir, 0, 0 } },
 	{ "ClearSkipDir", &cfgFuncClearStringList, { 0, 0, 0, &KcdConfig::cfgSkipDir, 0, 0 } },
 
@@ -997,7 +1023,7 @@ void	NeedSecureUserConfig()
 	Read configuration functions.
 *************************************************************************/
 
-void	LoadConfig(const string &confFile, int quiet, bool checkSecure = false)
+void	LoadConfig(const string &confFile, bool quiet, bool checkSecure = false)
 {
 	FILE	*file;
 	int	ret = 0;		// OK
@@ -1087,7 +1113,7 @@ void	LoadConfig(const string &confFile, int quiet, bool checkSecure = false)
 
 					if (!IsProfileValid(s, true)) {
 						cerr << progName
-						     << _(": invalid charactors in profile name\n");
+						     << _(": invalid characters in profile name\n");
 						PrintErrorCommand(configLine);
 						numError++;
 						continue;
@@ -1145,7 +1171,7 @@ void	LoadConfig(const string &confFile, int quiet, bool checkSecure = false)
 	}
 }
 
-void	LoadAllConfig(int quiet)
+void	LoadAllConfig(bool quiet)
 {
 	static int	loaded = 0;
 	
