@@ -23,6 +23,7 @@
 #include "scandir.h"
 #include "strmisc.h"
 #include "cstrlib.h"
+#include "gentree.h"
 
 sptr_list<DirectoryEntry> dirTree;
 
@@ -143,7 +144,7 @@ void	LoadDirHeader(gzFile filegz)
 		throw ErrorBadFileFormat();
 }
 
-void	LoadDirFile(int quiet)
+void	LoadDirFile(bool quiet)
 {
 	FILE	*file;
 	gzFile	filegz;
@@ -310,3 +311,76 @@ void	WriteDirFile()
 	gzclose(file);			// Close ~/.kcd.save.gz 
 }
 
+/*************************************************************************
+	Expand every symbolic link to real directory names
+*************************************************************************/
+
+void	ResolveSymLink(sptr_list<DirectoryEntry> *tree, 
+		       sptr<DirectoryEntry> &d, const string &current_dir)
+{
+	int	ret;
+	
+	if (k_access(current_dir, F_OK))
+						// Shouldn't come here
+		d->isLinkDestSkip = 3;		// Not found
+	else if (k_access(current_dir, X_OK)) {
+		d->isLinkDestSkip = 0;
+		d->isLinkDestUnreadable = 1;	// Cannot change to
+						// this dir
+	}
+	else if (k_access(current_dir, R_OK)) {
+		d->isLinkDestSkip = 0;
+		d->isLinkDestUnreadable = 2;	// Cannot read dir
+	}
+	else {
+		d->isLinkDestUnreadable = 0;	// Access OK
+
+		ret = k_chdir(current_dir);
+		if (ret == 0) {
+					// Return empty string if unreadable
+					// otherwise it's the current working 
+					// dir with no symbolic link involved
+			string	linked_dir = k_getcwd();
+			if (!linked_dir.size()) {
+				d->isLinkDestSkip = 3;
+				return;
+			}
+			d->UpdateLinkDest(linked_dir);
+
+			FindDirInfo *dir_info = FindDir(tree, linked_dir, false, false);
+			if (dir_info)
+				d->isLinkDestSkip = 0;
+			else
+				d->isLinkDestSkip = 1;
+			delete dir_info;
+		}
+		else {				// Shouldn't come here
+			d->isLinkDestSkip = 3;
+		}
+	}
+}
+
+void	RecursiveResolveSymLink(sptr_list<DirectoryEntry> *tree,
+				sptr_list<DirectoryEntry> &d,
+				const string &current_dir)
+{
+	for (sptr_list<DirectoryEntry>::iterator iter = d.begin();
+	     iter != d.end(); ++iter) {
+
+		string new_dir = current_dir;
+		new_dir += (*iter)->GetNameStr();
+
+		if ((*iter)->IsSymLink()) {
+			ResolveSymLink(tree, *iter, new_dir);
+		}
+		else {
+						// Append trailing slash
+			if (new_dir[new_dir.size()-1] != '/')
+				new_dir += '/';
+
+						// Recursion...
+			RecursiveResolveSymLink(tree, (*iter)->subDir, new_dir);
+		}
+	}
+}
+
