@@ -1,6 +1,6 @@
 /*
 	dirtree.h	Directory Tree Functions Header
-	Copyright (c) 2000, 2002 Kriang Lerdsuwanakij
+	Copyright (c) 2000,2002,2003 Kriang Lerdsuwanakij
 	email:		lerdsuwa@users.sourceforge.net
 
 	This program is free software; you can redistribute it and/or modify
@@ -33,9 +33,13 @@ extern string	bookmarkFile;
 time_t	GetScanTime();
 void	SetScanTime(time_t t);
 
-void	LoadDirFile(int quiet);
+void	LoadDirFile(bool quiet);
 void	WriteDirFile();
 
 int	operator < (const DirectoryEntry &a, const DirectoryEntry &b);
 
+void	RecursiveResolveSymLink(sptr_list<DirectoryEntry> *tree, 
+				sptr_list<DirectoryEntry> &d,
+				const string &current_dir);
+
 #endif	/* __K_DIRTREE_H */
