@@ -1,6 +1,6 @@
 /*
 	dirutil.h	Directory Utility Functions Header
-	Copyright (c) 2000, 2001 Kriang Lerdsuwanakij
+	Copyright (c) 2000, 2001,2003 Kriang Lerdsuwanakij
 	email:		lerdsuwa@users.sourceforge.net
 
 	This program is free software; you can redistribute it and/or modify
@@ -26,6 +26,6 @@
 
 USING_NAMESPACE_STD;
 
-string	ExpandDirectory(const string &src, int quote = 0);
+string	ExpandDirectory(const string &src, bool quote = false);
 
 #endif	/* __K_DIRUTIL_H */
