@@ -1,6 +1,6 @@
 /*
 	kcdmain.cc	Kriang's Change Directory
-	Copyright (c) 1996,1997,1998,1999,2000,2001,2002,2003 Kriang Lerdsuwanakij
+	Copyright (c) 1996-9,2000-2,2003 Kriang Lerdsuwanakij
 	email:		lerdsuwa@users.sourceforge.net
 
 	This program is free software; you can redistribute it and/or modify
@@ -38,6 +38,7 @@
 #include "strmisc.h"
 #include "cstrlib.h"
 #include "dirutil.h"
+#include "dirtree.h"
 
 // setupcurses.h is included in miscobj.h
 
@@ -50,10 +51,6 @@ string	bookmarkFile;		// For home dir + ".kcd.bookmark.gz"
 string	dirFile;		// For home dir + ".kcd.newdir"
 string	confLocalFile;		// For home dir + ".kcd.conf"
 
-int	forceFullScan = 0;
-int	forceQuiet = -1;		// Set to 0 or 1 by -rQ and -rq
-
-
 /*************************************************************************
 	Display program version, help.
 *************************************************************************/
@@ -92,26 +89,30 @@ void	PrintBanner()
 void	Help()
 {
 	PrintBanner();
-	gtout(cout, _("Usage:   %$ [PATTERN]\n"
+	gtout(cout, _("Usage:   %$ [-B] [PATTERN] [NUMBER]\n"
 		      "  or:    %$ [OPTION]\n")) << progName << progName;
 	cout << _("Available options:\n");
 	cout << _("     -b [PATTERN]   Display bookmarked directories matching PATTERN\n"
 		  "                    (default = display all)\n"
 		  "     -ba [DIR ...]  Bookmark DIR list (default = current directory)\n"
 		  "     -br [DIR ...]  Remove DIR list bookmark\n"
-		  "     -bx [FILE]     (Deprecated) Export bookmark to FILE\n"
 		  "     -B             Use entire tree even a bookmarked match is found\n");
 	cout << _("     --config       Display current configuration\n"
 		  "     --configattr   Display current screen attribute configuration\n"
 		  "     --features     Display features included during compilation\n"
 		  "     -h, --help     Display this help\n"
 		  "     --helpinst     Display help about shell alias/function installation\n");
-	cout << _("     -p NAME        Use configuration profile NAME\n");
+	cout << _("     -p NAME        Use configuration profile NAME.  If used, this must be\n"
+		  "                    the first option in the command line\n");
 	cout << _("     -r             Rescan directory tree\n"
 		  "     -rf            Rescan directory tree using full rescan mode\n"
 		  "     -rp DIR        Rescan part of directory tree beginning at DIR\n"
 		  "     -rq            Rescan directory tree, do not display progress\n"
 		  "     -rQ            Rescan directory tree, display progress\n"
+		  "     -t [DIR]       Display DIR as directory tree (default = current\n"
+		  "                    directory)\n"
+		  "     -tr [DIR]      Like -t but rescan directory tree before display\n"
+		  "     -T             Display full directory tree\n"
 		  "     -v, --version  Display version number\n\n");
 }
 
@@ -207,8 +208,9 @@ string	home_dir;
 void	SetSaveFile()
 {
 					// Initialize ~/.kcd.save.*.gz,
-	if (getenv("KCD_DIRTREE") && strlen(getenv("KCD_DIRTREE"))) {
-		saveFile = getenv("KCD_DIRTREE");
+	const char *env = getenv("KCD_DIRTREE");
+	if (env && strlen(env)) {
+		saveFile = env;
 	}
 	else {
 		saveFile = home_dir;
@@ -218,8 +220,9 @@ void	SetSaveFile()
 	}
 
 					// Initialize ~/.kcd.bookmark.*.gz,
-	if (getenv("KCD_BOOKMARK") && strlen(getenv("KCD_BOOKMARK"))) {
-		bookmarkFile = getenv("KCD_BOOKMARK");
+	env = getenv("KCD_BOOKMARK");
+	if (env && strlen(env)) {
+		bookmarkFile = env;
 	}
 	else {
 		bookmarkFile = home_dir;
@@ -230,6 +233,10 @@ void	SetSaveFile()
 
 void	mainReal(int argc, char *argv[])
 {
+	const char *env = getenv("IFS");
+	if (env && env[0] != 0 && env[0] != ' ' && env[0] != '\t')
+		throw ErrorGenericFile(_("invalid IFS environment variable setting"));
+
 #ifdef HAVE_SETENV
 	setenv("IFS", " \t\n", 1);	// Security precaution
 	unsetenv("NLSPATH");
@@ -256,16 +263,18 @@ void	mainReal(int argc, char *argv[])
 	if (home_dir[home_dir.size()-1] != '/')	// Not end with "/"
 		home_dir += '/';	// Need to add a "/" after home dir
 
-	if (getenv("KCD_TEMP") && strlen(getenv("KCD_TEMP"))) {
-		dirFile = getenv("KCD_TEMP");
+	env = getenv("KCD_TEMP");
+	if (env && strlen(env)) {
+		dirFile = env;
 	}
 	else {
 		dirFile = home_dir;
 		dirFile += ".kcd.newdir";	// Add appropriate filename
 	}
 
-	if (getenv("KCD_CONFIG") && strlen(getenv("KCD_CONFIG"))) {
-		confLocalFile = getenv("KCD_CONFIG");
+	env = getenv("KCD_CONFIG");
+	if (env && strlen(env)) {
+		confLocalFile = env;
 		NeedSecureUserConfig();		// Turn on security check
 	}
 	else {
@@ -286,6 +295,7 @@ void	mainReal(int argc, char *argv[])
 
 		bool	rescan = false;
 		bool	entire_tree = false;
+		bool	forceFullScan = false;
 
 		vector<string>	partial_dir;
 
@@ -412,7 +422,9 @@ void	mainReal(int argc, char *argv[])
 			}
 						// Profile
 			else if (strcmp(argv[argcCur], "-p") == 0) {
-				if (argcLeft >= 2)
+				if (argcCur != 1)
+					throw ErrorGenericCommandLine(_("`-p\' must be the first option used"));
+				else if (argcLeft >= 2)
 					SetCurrentProfile(argv[argcCur+1]);
 				else
 					throw ErrorGenericCommandLine(_("one argument required for `-p\'"));
@@ -443,25 +455,54 @@ void	mainReal(int argc, char *argv[])
 				SetSaveFile();
 				RemoveBookmarks(argc, argv, argcCur+1);
 				return;
-			}
-						// Export bookmark
-			else if (strcmp(argv[argcCur], "-bx") == 0) {
-				SetSaveFile();
-
-				cout << flush;		// Avoid out-of-order display
-				cerr << progName << _(": warning: `-bx' option is deprecated\n");
-
-				if (argcLeft >= 3)
-					throw ErrorGenericCommandLine(_("too many arguments for `-bx\'"));
-				else if (argcLeft == 2)
-					ExportBookmarks(argv[argcCur+1]);
-				else
-					ExportBookmarks("");
-				return;
 			}
 						// Use entire tree
 			else if (strcmp(argv[argcCur], "-B") == 0) {
 				entire_tree = true;
+			}
+						// Display tree
+			else if (strcmp(argv[argcCur], "-t") == 0) {
+				SetSaveFile();
+
+				if (argcLeft >= 3)
+					throw ErrorGenericCommandLine(_("too many arguments for `-t\'"));
+				else if (argcLeft == 2) {
+					LoadDirFile(true);
+					DisplayTree(argv[argcCur+1]);
+				}
+				else {
+					LoadDirFile(true);
+					DisplayTree("");
+				}
+				return;
+			}
+						// Display tree with rescan
+			else if (strcmp(argv[argcCur], "-tr") == 0) {
+				LoadAllConfig(false);
+
+				SetSaveFile();
+
+				if (argcLeft >= 3)
+					throw ErrorGenericCommandLine(_("too many arguments for `-tr\'"));
+				else if (argcLeft == 2) {
+					LoadDirFile(true);
+					DisplayTree(argv[argcCur+1], true);
+				}
+				else {
+					LoadDirFile(true);
+					DisplayTree("", true);
+				}
+				return;
+			}
+						// Display full tree
+			else if (strcmp(argv[argcCur], "-T") == 0) {
+				SetSaveFile();
+
+				if (argcLeft >= 2)
+					throw ErrorGenericCommandLine(_("argument not allowed for `-T\'"));
+				LoadDirFile(true);
+				DisplayFullTree();
+				return;
 			}
 						// Rescan dir.
 			else if (strncmp(argv[argcCur], "-r", 2) == 0) {
@@ -469,16 +510,18 @@ void	mainReal(int argc, char *argv[])
 
 				bool	use_partial_dir = false;
 
+				LoadAllConfig(false);
+
 				for (char *p = argv[argcCur]+2; *p; ++p) {
 					switch (*p) {
 						case 'q':
-							forceQuiet = 1;
+							kcdConfig.ForceQuiet(true);
 							break;
 						case 'Q':
-							forceQuiet = 0;
+							kcdConfig.ForceQuiet(false);
 							break;
 						case 'f':
-							forceFullScan = 1;
+							forceFullScan = true;
 							break;
 						case 'p':
 							if (argcLeft < 2) {
@@ -513,6 +556,17 @@ void	mainReal(int argc, char *argv[])
 
 				if (argcLeft == 1 && rescan == false)
 					CD(argv[argcCur], entire_tree);
+				else if (argcLeft == 2 && rescan == false) {
+					try {
+						size_t u = StringToUnsigned(argv[argcCur+1], 0);
+						if (u == 0)
+							throw ErrorRange();
+						CD(argv[argcCur], entire_tree, u);
+					}
+					catch (ErrorRange &) {
+						throw ErrorGenericCommandLine(_("invalid match number"));
+					}
+				}
 				else			// Too many arguments
 					throw ErrorGenericCommandLine(_("too many arguments"));
 				return;
