@@ -1435,7 +1435,7 @@ void	HyperDocument::ProcessHypertext(char *buffer, size_t length, WINDOW *pad)
 								my_wattr_get(pad, &oldAttr, &oldPair);
 								wattrset(pad, A_NORMAL);
 							}
-							for (k = x; k <= prevCol; k++) {
+							for (k = x; k <= static_cast<size_t>(prevCol); k++) {
 								if (pad) {
 									wmove(pad, prevRow, k);
 									ch = winch(pad);
@@ -1590,11 +1590,11 @@ void	HyperDocument::ProcessHypertext(char *buffer, size_t length, WINDOW *pad)
 	else {				// *** Move check to loop above ??
 		if (curRow != numRow-1 && curRow > scrRow) {
 			throw ErrorGenericSyntax(_("hypertext size calculation not match actual hypertext parse\n"
-						   "Number of row: %$ (calc.) %$ (parse)"),
+						   "Number of row: %$ (calculatation) %$ (parse)"),
 						 numRow, curRow+1);
 		}
 
-		for (i = curRow; i < numRow; i++) {
+		for (i = curRow; i < static_cast<size_t>(numRow); i++) {
 			numChar[i] = curColumn;
 			curColumn = 0;
 		}
@@ -1843,7 +1843,7 @@ void	HyperDocument::DrawBegin(WINDOW *pad)
 	curRow = 0;
 	curColumn = 0;
 	numChar = new short[numRow];
-	for (size_t i = 0; i < numRow; ++i)
+	for (size_t i = 0; i < static_cast<size_t>(numRow); ++i)
 		numChar[i] = numColumn;
 
 	numNestA = 0;
@@ -1999,8 +1999,9 @@ void	HyperDocument::DrawString(WINDOW *pad, const char *s)
 				wchar_t wc;
 				static mbstate_t state;
 				memset(&state, 0, sizeof(mbstate_t));
-				int ret = mbrtowc(&wc, s+i, length-i, &state);
-				if (ret <= 0)
+				size_t ret = mbrtowc(&wc, s+i, length-i, &state);
+				if (ret == 0 || ret == static_cast<size_t>(-1)
+				    || ret == static_cast<size_t>(-2))
 					throw ErrorBadSequence();
 
 						// FIXME: Check if printable logic correct?
