@@ -1,6 +1,6 @@
 /*
 	miscobj.cc	Various NCurses C++ Classes
-	Copyright (c) 1996-8,2000,2001 Kriang Lerdsuwanakij
+	Copyright (c) 1996-8,2000,2001,2003 Kriang Lerdsuwanakij
 	email:		lerdsuwa@users.sourceforge.net
 
 	This program is free software; you can redistribute it and/or modify
@@ -465,6 +465,7 @@ void	NCurses::InitMore(WINDOW *win)
 		cbreak();
 		noecho();
 		typeahead(-1);
+		raw();
 		if (has_colors() == TRUE) {
 			start_color();
 		}
@@ -482,8 +483,14 @@ void	NCurses::End()
 		isInitScr = 0;
 
 		if (!IsRedirect()) {
+			if (isInitScrMore) {
 				// Opposite of ncurses start_color()
-			putp(tigetstr("sgr0"));		// Exit attribute mode
+				putp(tigetstr("sgr0"));		// Exit attribute mode
+				noraw();
+				echo();
+				nocbreak();
+				nl();
+			}
 			endwin();
 		}
 	}
