@@ -1,6 +1,6 @@
 /*
 	scrnman.h	Screen Manager Header
-	Copyright (c) 1997-8,2000 Kriang Lerdsuwanakij
+	Copyright (c) 1997-8,2000,2007 Kriang Lerdsuwanakij
 	email:		lerdsuwa@users.sourceforge.net
 
 	This program is free software; you can redistribute it and/or modify
@@ -42,11 +42,13 @@ class NCGeometryManagerBase {
 		int	GetMode()		{ return mode; }
 		
 		virtual void	SetWinRect(int id, NCRect &rect) = 0;
+		virtual ~NCGeometryManagerBase() {}
 };
 
 /*************************************************************************
 	Screen manager base class
 *************************************************************************/
+class NCWindowBase;
 
 class NCScreenManager {
 	friend	class NCWindowBase;	// Allow access to 
