@@ -35,14 +35,14 @@ USING_NAMESPACE_STD;
 
 class StatusWindowBase : public NCWindowBase {
 	protected:
-		int	statusNo;
-		int	maxStatus;
+		size_t	statusNo;
 	public:
+		virtual size_t	MaxStatus() = 0;
 		virtual void	SetTitle(const char *title_) = 0;
 		virtual void	SetTitle(const string &title_) = 0;
 		virtual void	NextStatus() = 0;
 		virtual void	SetCount(size_t /*count_*/) {}
-		StatusWindowBase(NCScreenManager &scrnMan_, int id_, int _maxStatus);
+		StatusWindowBase(NCScreenManager &scrnMan_, int id_);
 };
 
 
@@ -62,6 +62,7 @@ class khStatusWindow : public StatusWindowBase {
 		virtual void	DoResize();
 		virtual void	DoUpdate();
 		
+		virtual size_t	MaxStatus() { return 1; }
 		virtual void	SetTitle(const char *title_);
 		virtual void	SetTitle(const string &title_);
 		virtual void	NextStatus();
@@ -82,9 +83,9 @@ class khURLWindow : public StatusWindowBase {
 		string		switch_disp;
 		size_t		switch_disp_width;
 
-		static char	*statKey1;
-		static char	*statKey2;
-		static char	*statKey3;
+		char	*statKey1;
+		char	*statKey2;
+		char	*statKey3;
 
 #ifdef NCURSES_MOUSE_VERSION
 		virtual void	ProcessMouse(MEVENT &event);
@@ -94,6 +95,7 @@ class khURLWindow : public StatusWindowBase {
 		virtual void	DoResize();
 		virtual void	DoUpdate();
 		
+		virtual size_t	MaxStatus() { return DISP_NUMDISPLAY; }
 		virtual void	SetTitle(const char *title_);
 		virtual void	SetTitle(const string &title_);
 		virtual void	NextStatus();
@@ -111,11 +113,12 @@ class khURLWindowWithFind : public khURLWindow {
 		enum { DISP_KEYS4FIND = khURLWindow::DISP_NUMDISPLAY,
 			DISP_KEYSFIND,
 			DISP_NUMDISPLAYFIND };
-		static char	*statKey4WithFind;
-		static char	*statKeyFind;
-		static char	*statKeyCtrlF;
+		char	*statKey4WithFind;
+		char	*statKeyFind;
+		char	*statKeyCtrlF;
 
 	public:
+		virtual size_t	MaxStatus() { return DISP_NUMDISPLAYFIND; }
 		void	ProcessCtrl(char c, bool s);
 		virtual void	DrawStatusBar(int num = -1);
 		khURLWindowWithFind(NCScreenManager &scrnMan_, int id_);
